@@ -24,8 +24,6 @@
 
 #ifndef QT_NO_PHONON_EFFECT
 
-QT_BEGIN_NAMESPACE
-
 class QObject;
 
 namespace Phonon
@@ -41,18 +39,23 @@ class AudioEffect : public Effect
     Q_OBJECT
 public:
     AudioEffect (Backend *backend, int effectId, QObject *parent);
+
 protected:
     GstElement* createEffectBin();
-    GstElement* audioElement() { return m_effectBin; }
+
+    GstElement* audioElement() const {
+        return effectBin();
+    }
+
+private:
     QString m_effectName;
+
 };
 
 } // namespace Gstreamer
 } // namespace Phonon
 
 
-QT_END_NAMESPACE
-
 #endif //QT_NO_PHONON_EFFECT
 
 #endif // Phonon_GSTREAMER_AUDIOEFFECT_H
