@@ -24,8 +24,6 @@
 #include <QtCore/QList>
 #include <QtCore/QStringList>
 
-QT_BEGIN_NAMESPACE
-
 namespace Phonon
 {
 namespace Gstreamer
@@ -39,12 +37,13 @@ class MediaObject;
 class Backend : public QObject, public BackendInterface
 {
     Q_OBJECT
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
+    Q_PLUGIN_METADATA(IID "org.kde.phonon.gstreamer" FILE "phonon-gstreamer.json")
+#endif
     Q_INTERFACES(Phonon::BackendInterface)
 
 public:
-
-    enum DebugLevel {NoDebug, Warning, Info, Debug};
-    Backend(QObject *parent = 0, const QVariantList & = QVariantList());
+    explicit Backend(QObject *parent = 0, const QVariantList & = QVariantList());
     virtual ~Backend();
 
     DeviceManager* deviceManager() const;
@@ -62,9 +61,6 @@ public:
     bool disconnectNodes(QObject *, QObject *);
     bool endConnectionChange(QSet<QObject *>);
 
-    DebugLevel debugLevel() const;
-
-    void logMessage(const QString &message, int priority = 2, QObject *obj = 0) const;
     // 'retry' indicates that we'd like to check the deps after a registry rebuild
     bool checkDependencies(bool retry = false) const;
 
@@ -77,13 +73,10 @@ private:
 
     DeviceManager *m_deviceManager;
     EffectManager *m_effectManager;
-    DebugLevel m_debugLevel;
     bool m_isValid;
 };
 
 }
 } // namespace Phonon::Gstreamer
 
-QT_END_NAMESPACE
-
 #endif // Phonon_GSTREAMER_BACKEND_H
