@@ -97,8 +97,9 @@ GstFlowReturn StreamReader::read(quint64 pos, int length, char *buffer)
     DEBUG_BLOCK;
 
     // If we got unlocked before grabbing the mutex -> return
-    if (!m_locked)
-        return GST_FLOW_UNEXPECTED;
+    if (!m_locked) {
+        return GST_FLOW_EOS;
+    }
 
     if (currentPos() != pos) {
         if (!streamSeekable()) {
@@ -118,13 +119,14 @@ GstFlowReturn StreamReader::read(quint64 pos, int length, char *buffer)
 
         // Abort instantly if we got unlocked, whether we got sufficient data or not
         // is absolutely unimportant at this point.
-        if (!m_locked)
-            return GST_FLOW_UNEXPECTED;
+        if (!m_locked) {
+            return GST_FLOW_EOS;
+        }
 
         if (oldSize == currentBufferSize()) {
             // We didn't get any data, check if we are at the end of stream already.
             if (m_eos) {
-                return GST_FLOW_UNEXPECTED;
+                return GST_FLOW_EOS;
             }
         }
     }
